@@ -3,8 +3,10 @@ import logging
 import os
 import re
 from tempfile import NamedTemporaryFile
+from xml.dom import ValidationErr
 
 from appdirs import user_config_dir
+from packaging import version
 
 try:
     from qgrid import show_grid
@@ -37,6 +39,8 @@ config_dir = user_config_dir(__name__.split(".")[0], False)
 
 logger = logging.getLogger("SensiML")
 
+__version__ = "2022.3.0"
+
 
 def project_set(func):
     def wrapper(*args, **kwargs):
@@ -104,15 +108,14 @@ def print_list(func):
 
 
 class Client(object):
-    # Server Minimum Version For Compatibility
-    __minversion__ = "2019.1.0"
-
     def __init__(
         self,
         server="https://sensiml.cloud/",
         path="connect.cfg",
         use_jedi=False,
-        **kwargs
+        insecure=False,
+        skip_validate=False,
+        **kwargs,
     ):
 
         self._project = None
@@ -120,10 +123,11 @@ class Client(object):
         auth_url = server + "oauth/"
 
         self._connection = Connection(
-            server=server, auth_url=auth_url, path=path, **kwargs
+            server=server, auth_url=auth_url, path=path, insecure=insecure, **kwargs
         )
 
-        self.validate_client_version(kwargs.get("skip_validate", True))
+        if not self.validate_client_version(skip_validate):
+            return
         self.projects = Projects(self._connection)
         self.datasets = DataSets()
         self.functions = Functions(self._connection)
@@ -151,21 +155,28 @@ class Client(object):
         """Perform a Validation check to see if this version of SensiML is up to date with the latest."""
 
         if skip_validate:
-            return
+            return True
 
         url = "version"
 
         response = self._connection.request("get", url)
         response_data, err = utility.check_server_response(response)
 
-        if response_data["SensiML_Python_Library_Windows"] != self.__minversion__:
+        if version.parse(
+            response_data["SensiML_Python_Library_Windows_Minimum"]
+        ) > version.parse(__version__):
             print(
-                "The SensiML Python SDK is out of date. Update before connecting to the server."
+                f"Error: The SensiML Python SDK is out of date.\n\n\tCurrent installed version = {__version__}. \n\tMinimum supported version = {response_data['SensiML_Python_Library_Windows_Minimum']}."
             )
             print(
-                "In order to update the SensiML Python SDK use 'pip install sensiml -U'"
+                "\nTo update the SensiML Python SDK run \n\n\tpip install sensiml -U\n\nIf you are in a notebook, you can execute the following in a cell then restart the shell.\n\n\t!pip install sensiml -U"
             )
-            raise Exception("SensiML Python SDK is out of date.")
+            print(
+                "\nTo disable this validation check and connect anyway you can use the skip_validate parameter\n\n\tclient = Client(skip_validate=True)"
+            )
+            return False
+
+        return True
 
     def logout(self, name=None):
         """Logs out of the current connection."""
