@@ -1,21 +1,16 @@
-from sensiml.datamanager.functions import Functions
-from sensiml.datamanager.platformdescriptions import PlatformDescriptions
+from sensiml.datamanager.capture_configurations import CaptureConfigurations
 from sensiml.datamanager.clientplatformdescriptions import ClientPlatformDescriptions
-from sensiml.datamanager.pipelineseeds import PipelineSeeds
 from sensiml.datamanager.featurefiles import FeatureFiles
+from sensiml.datamanager.functions import Functions
 from sensiml.datamanager.projects import Projects
 from sensiml.datamanager.segmenter import SegmenterSet
-from sensiml.datamanager.capture_configurations import CaptureConfigurations
 from sensiml.datamanager.team import Team
 
-
 __all__ = [
     "Functions",
     "FeatureFiles",
     "Projects",
     "SegmenterSet",
-    "PipelineSeeds",
-    "PlatformDescriptions",
     "ClientPlatformDescriptions",
     "CaptureConfigurations",
     "Team",
