@@ -1,14 +1,15 @@
-import logging
-import time
 import datetime
-from requests.exceptions import *
+import logging
+import os.path
+import time
+
+import pandas as pd
 import sensiml.base.utility as utility
+from pandas import DataFrame
+from requests.exceptions import *
 from sensiml.datamanager.errors import CaptureUploadFailureError
 from sensiml.datamanager.metadata_relationship import MetadataRelationshipSet
 from sensiml.datamanager.segment import SegmentSet
-import pandas as pd
-from pandas import DataFrame
-import os.path
 
 EXCEPTION_STATES = frozenset(["FAILURE", "RETRY", "REVOKED"])
 
@@ -230,44 +231,6 @@ class Capture(object):
         )
         return Capture(**new_dict)
 
-    def data(self, cloud=True):
-        """Calls the REST API and retrieves a capture's sensor data.
-
-        Returns:
-            data (DataFrame): all sensor data associated with the capture
-        """
-        url = "project/{0}/capture/{1}/capture-sample/".format(
-            self._project.uuid, self.uuid
-        )
-        data = []
-
-        if cloud:
-            try:
-                response = self._connection.request("get", url)
-                response_data, err = utility.check_server_response(response)
-                if err is False:
-                    data = DataFrame(response_data)
-            except HTTPError:
-                utility.read_response_json_data(response)
-                raise
-
-        else:
-            try:
-                paged_response = self._connection.paged_request("get", url)
-                for results in paged_response:
-                    data.append(DataFrame(results))
-            except HTTPError:
-                utility.read_response_json_data(paged_response.response)
-                raise
-            data = pd.concat(data)
-
-        # Post-processing to get numeric index
-        data["sequence"] = data.sequence.astype(int)
-        data = data.sort_values(by="sequence").reset_index(drop=True)
-        data.drop("sequence", axis=1, inplace=True)
-
-        return data
-
     # methods to make this instance hashable and comparable
     def __hash__(self):
         return hash(self._uuid)
