@@ -9,10 +9,12 @@ class FeatureFile(Base):
 
     _fields = ["uuid", "name", "created_at", "last_modified", "is_features"]
 
-    def __init__(self, connection, project, name="", path="", is_features=True):
+    def __init__(
+        self, connection, project, name="", path="", is_features=True, uuid=None
+    ):
         self._connection = connection
         self._project = project
-        self.uuid = None
+        self.uuid = uuid
         self._created_at = None
         self._is_features = is_features
         self.name = name
