@@ -31,7 +31,7 @@ class KnowledgePackException(Exception):
 class KnowledgePack(VisualizeMixin):
     """Base class for a KnowledgePack"""
 
-    def __init__(self, connection, project_uuid, sandbox_uuid):
+    def __init__(self, connection, project_uuid, sandbox_uuid=""):
         """Initializes a KnowledgePack instance
 
         Args:
@@ -103,6 +103,11 @@ class KnowledgePack(VisualizeMixin):
         """The model's parameters"""
         return self._neuron_array
 
+    @property
+    def model_configuration(self):
+        """Model Configuration"""
+        return self.device_configuration
+
     @property
     def model_results(self):
         """The model results associated with the KnowledgePack (in JSON form)"""
@@ -495,8 +500,11 @@ class KnowledgePack(VisualizeMixin):
 
                 return response
 
+    def rename(self, name):
+        return self.save(name)
+
     def save(self, name):
-        """Save a knowledgepack with a name.
+        """Rename a knowledge pack
 
         Returns:
             (DataFrame or ModelResultSet): result of executed pipeline, specified by the sandbox
@@ -545,17 +553,38 @@ class KnowledgePack(VisualizeMixin):
     def download_library(
         self, folder="", run_async=True, platform=None, renderer=None, *args, **kwargs
     ):
-        print("this API was removed. use download_library_v2")
+        self.download_library_v2(
+            folder=folder,
+            run_async=run_async,
+            platform=platform,
+            renderer=renderer,
+            *args,
+            **kwargs,
+        )
 
     def download_source(
         self, folder="", run_async=True, platform=None, renderer=None, *args, **kwargs
     ):
-        print("this API was removed. use download_source_v2")
+        self.download_source_v2(
+            folder=folder,
+            run_async=run_async,
+            platform=platform,
+            renderer=renderer,
+            *args,
+            **kwargs,
+        )
 
     def download_binary(
         self, folder="", run_async=True, platform=None, renderer=None, *args, **kwargs
     ):
-        print("this API was removed. use download_library_v2")
+        self.download_binary_v2(
+            folder=folder,
+            run_async=run_async,
+            platform=platform,
+            renderer=renderer,
+            *args,
+            **kwargs,
+        )
 
     def download_library_v2(
         self, folder="", run_async=True, platform=None, renderer=None, *args, **kwargs
@@ -575,7 +604,7 @@ class KnowledgePack(VisualizeMixin):
             platform=platform,
             renderer=renderer,
             *args,
-            **kwargs
+            **kwargs,
         )
 
     def download_source_v2(
@@ -596,7 +625,7 @@ class KnowledgePack(VisualizeMixin):
             platform=platform,
             renderer=renderer,
             *args,
-            **kwargs
+            **kwargs,
         )
 
     def download_binary_v2(
@@ -617,7 +646,7 @@ class KnowledgePack(VisualizeMixin):
             platform=platform,
             renderer=renderer,
             *args,
-            **kwargs
+            **kwargs,
         )
 
     def get_sandbox_device_config(self):
@@ -637,12 +666,10 @@ class KnowledgePack(VisualizeMixin):
         platform=None,
         renderer=None,
         *args,
-        **kwargs
+        **kwargs,
     ):
         _path = r"{0}".format(folder)
-        url = "project/{0}/knowledgepack/{2}/generate_{3}/v2".format(
-            self._project_uuid, self._sandbox_uuid, self.uuid, bin_or_lib
-        )
+        url = f"project/{self._project_uuid,}/knowledgepack/{ self.uuid}/generate_{bin_or_lib}/v2"
         # config = self._sandbox.device_config.copy() # get a regular dictionary
 
         if platform is not None and type(platform) is ClientPlatformDescription:
@@ -792,54 +819,98 @@ class KnowledgePack(VisualizeMixin):
 
         return self._feature_file_cache
 
+    def create(self):
+        """Create a new knowledge pack on the server using the internal data for this model
+
+        Returns:
+            KnowledgePack object
+        """
+
+        print(
+            "Creating Knowledge Packs is currently beta and the API is subject to change."
+        )
+
+        data = {
+            "project": self.project_uuid,
+            "pipeline_summary": self.pipeline_summary,
+            "query_summary": self.query_summary,
+            "feature_summary": self.feature_summary,
+            "class_map": self.class_map,
+            "sensor_summary": self.sensor_summary,
+            "transform_summary": self.transform_summary,
+            "knowledgepack_summary": self.knowledgepack_summary,
+            "sandbox": self.sandbox_uuid,
+            "name": self.name,
+            "model_parameters": self.model_parameters,
+            "model_configuration": self.model_configuration,
+        }
+
+        url = f"project/{self.project_uuid}/knowledgepack/"
+        response = self._connection.request("post", url, json=data)
+        response_data, err = utility.check_server_response(response)
+        if err is False:
+            kp = KnowledgePack(
+                self._connection,
+                response_data.get("project_uuid"),
+                response_data.get("sandbox_uuid"),
+            )
+            kp.initialize_from_dict(response_data)
+            return kp
+
+        return response_data
+
+    def export(self):
+        """Export a Knowledge Pack Model
+
+        Returns:
+            Knowledge Pack Export Dict
+        """
+
+        url = f"knowledgepack/{self.uuid}/export/"
+        response = self._connection.request("get", url)
+        response_data, err = utility.check_server_response(response)
+        if err is False:
+            return response_data
+
+        return response
+
     def initialize_from_dict(self, init_dict):
         self._init_dict = init_dict
         self._uuid = init_dict["uuid"]
         self._name = init_dict["name"]
-        self._configuration_index = init_dict["configuration_index"]
-        self._model_index = init_dict["model_index"]
-        self._execution_time = init_dict["execution_time"]
-        try:
-            self._model_results = json.loads(init_dict["model_results"])
-            self._device_configuration = json.loads(init_dict["device_configuration"])
-            self._class_map = json.loads(init_dict["class_map"])
-            self._cost_summary = json.loads(init_dict["cost_summary"])
-            self._pipeline_summary = json.loads(init_dict["pipeline_summary"])
-            self._query_summary = json.loads(init_dict["query_summary"])
-            self._feature_summary = json.loads(init_dict["feature_summary"])
-            self._transform_summary = json.loads(init_dict["transform_summary"])
-            self._sensor_summary = json.loads(init_dict["sensor_summary"])
-            self._neuron_array = json.loads(init_dict["neuron_array"])
-            self._project_name = json.loads(init_dict["project_name"])
-            self._sandbox_name = json.loads(init_dict["sandbox_name"])
-            self._feature_file_uuid = json.loads(init_dict["feature_file_uuid"])
-            self._training_metrics = json.loads(init_dict("training_metrics"))
-            self._knowledgepack_summary = json.loads(
-                init_dict.get("knowledgepack_summary", "")
-            )
-            self._knowledgepack_description = json.loads(
-                init_dict.get("knowledgepack_description", "")
-            )
+        self._configuration_index = init_dict.get("configuration_index", None)
+        self._model_index = init_dict.get("model_index", None)
+        self._execution_time = init_dict.get("execution_time", None)
 
-        except:
-            self._model_results = init_dict["model_results"]
-            self._device_configuration = init_dict["device_configuration"]
-            self._class_map = init_dict["class_map"]
-            self._cost_summary = init_dict["cost_summary"]
-            self._pipeline_summary = init_dict["pipeline_summary"]
-            self._query_summary = init_dict["query_summary"]
-            self._feature_summary = init_dict["feature_summary"]
-            self._transform_summary = init_dict["transform_summary"]
-            self._sensor_summary = init_dict["sensor_summary"]
-            self._neuron_array = init_dict["neuron_array"]
-            self._project_name = init_dict["project_name"]
-            self._sandbox_name = init_dict["sandbox_name"]
-            self._feature_file_uuid = init_dict["feature_file_uuid"]
-            self._knowledgepack_summary = init_dict.get("knowledgepack_summary", None)
-            self._knowledgepack_description = init_dict.get(
-                "knowledgepack_description", None
-            )
-            self._training_metrics = init_dict.get("training_metrics", None)
+        self._class_map = init_dict["class_map"]
+        self._pipeline_summary = init_dict["pipeline_summary"]
+        self._query_summary = init_dict["query_summary"]
+        self._feature_summary = init_dict["feature_summary"]
+        self._transform_summary = init_dict["transform_summary"]
+        self._sensor_summary = init_dict["sensor_summary"]
+
+        self._neuron_array = (
+            init_dict.get("neuron_array")
+            if init_dict.get("neuron_array")
+            else init_dict.get("model_parameters")
+        )
+        self._device_configuration = (
+            init_dict.get("device_configuration")
+            if init_dict.get("device_configuration")
+            else init_dict.get("model_configuration")
+        )
+
+        self._model_results = init_dict.get("model_results", None)
+
+        self._cost_summary = init_dict.get("cost_summary", None)
+        self._project_name = init_dict.get("project_name")
+        self._sandbox_name = init_dict.get("sandbox_name")
+        self._feature_file_uuid = init_dict.get("feature_file_uuid")
+        self._knowledgepack_summary = init_dict.get("knowledgepack_summary", None)
+        self._knowledgepack_description = init_dict.get(
+            "knowledgepack_description", None
+        )
+        self._training_metrics = init_dict.get("training_metrics", None)
 
 
 def get_knowledgepack(kp_uuid, connection):
@@ -854,8 +925,12 @@ def get_knowledgepack(kp_uuid, connection):
     if err is False:
         kp = KnowledgePack(
             connection,
-            response_data.get("project_uuid"),
-            response_data.get("sandbox_uuid"),
+            response_data.get("project_uuid")
+            if response_data.get("project_uuid") is not None
+            else response_data.get("project"),
+            response_data.get("sandbox_uuid")
+            if response_data.get("sandbox_uuid") is not None
+            else response_data.get("sandbox"),
         )
         kp.initialize_from_dict(response_data)
         return kp
