@@ -8,19 +8,38 @@ from typing import Dict, List, Optional, Tuple
 import matplotlib.pyplot as plt
 import numpy as np
 import pandas as pd
-from matplotlib.lines import Line2D
 from pandas.core.frame import DataFrame
-from sensiml.dclproj.datasegments import DataSegment, DataSegments
+from sensiml.dclproj.datasegmentsv2 import (
+    DataSegmentsV2,
+    DataSegmentV2,
+    segment_list_to_datasegments,
+)
 from sensiml.dclproj.utils import mfcc, plot_segments_labels
+from sensiml.dclproj.vizualization import plot_segments
 
 
 class DCLProject:
-    def __init__(self):
-        self._path = None
+    """
+    The DCLProject class provides read-only access to the .dclproj file that is associated with a Data Capture Lab project. The
+    are a number of helper functions for visualizations and queries.
+
+
+    dclproj_path = '<PATH-To-File.dclproj>'
+
+    dcl = DCLProject(path=dclproj_path)
+
+
+    """
+
+    def __init__(self, path: Optional[str] = None):
+        self._path = path
         self._conn = None
         self._tables = None
         self._verbose = False
 
+        if self._path:
+            self.create_connection(self._path)
+
     @property
     def verbose(self):
         return self._verbose
@@ -229,7 +248,10 @@ class DCLProject:
             return df
 
         return df.merge(
-            self._list_captures_metadata(), left_on="name", right_on="capture"
+            self._list_captures_metadata(),
+            left_on="name",
+            right_on="capture",
+            how="left",
         ).drop("capture", axis=1)
 
     def list_sessions(self) -> DataFrame:
@@ -306,6 +328,22 @@ class DCLProject:
             .sort_values(by=["capture", "segmenter", "capture_sample_sequence_start"])
         )
 
+    def get_capture_stats(self, capture: str) -> Dict:
+        """Returns information about the capture
+
+        Args:
+            capture (str): name of capture
+
+        Returns:
+            Dict: information about the capture
+        """
+        capture_list = self.list_captures()
+
+        if capture not in capture_list.name.values:
+            raise Exception("Capture not found!")
+
+        return capture_list[capture_list.name == capture].to_dict(orient="records")[0]
+
     def get_capture_metadata(self, capture: str) -> DataFrame:
         """Gets the metadata for the specified capture
 
@@ -344,7 +382,7 @@ class DCLProject:
 
         labels = self.list_capture_segments(captures=captures, sessions=sessions)
 
-        M = DataSegments()
+        data_segments = DataSegmentsV2()
 
         cached_df = None
         capture_index = 4
@@ -365,20 +403,25 @@ class DCLProject:
                 tmp_df = self.get_capture(label[capture_index])
                 cached_df = label[capture_index]
 
-            M[index] = DataSegment(
-                tmp_df.loc[label[0] : label[1]],
-                segment_id=index,
-                session=label[5],
-                label_value=label[3],
-                uuid=label[2],
-                capture=label[4],
+            data_segments.append(
+                DataSegmentV2(
+                    segment_id=index,
+                    capture_sample_sequence_start=label[0],
+                    capture_sample_sequence_end=label[1],
+                    data=tmp_df.loc[label[0] : label[1]].values.T,
+                    columns=tmp_df.columns.to_list(),
+                    session=label[5],
+                    label_value=label[3],
+                    uuid=label[2],
+                    capture=label[4],
+                )
             )
 
-        return M
+        return data_segments
 
     def get_capture(self, capture_name: str) -> DataFrame:
         """
-        Returns the capture as a dataframe
+        Returns the capture as a DataFrame
 
         Args:
             capture_name (str): name of capture
@@ -387,6 +430,13 @@ class DCLProject:
         # TODO: read wave file if file is .wav
         ext = capture_name.split(".")[-1]
 
+        if not os.path.exists(os.path.join(self.data_dir, capture_name)):
+            raise Exception(
+                "File {} does not exist!".format(
+                    os.path.join(self.data_dir, capture_name)
+                )
+            )
+
         if ext == "csv":
             tmp_df = pd.read_csv(
                 os.path.join(self.data_dir, capture_name), index_col="sequence"
@@ -449,7 +499,7 @@ class DCLProject:
 
             >>> func = {'name':'sum','func':sum_columns, 'type':'transform'}
 
-            >>> dcl.plot_segment_labels(captures, session_name, columns=['sum], transforms=[func])
+            >>> dcl.plot_segment_labels(captures, session_name, columns=['sum'], transforms=[func])
 
             >>> # example of multiple transforms executed in order
 
@@ -492,9 +542,9 @@ class DCLProject:
             capture = self.get_capture(capture_name)
             M.append(capture)
 
-            plot_segments_on_capture(
-                capture,
+            plot_segments(
                 segments,
+                capture,
                 capture_name=capture_name,
                 labels=list(class_map.keys()),
                 current_start=current_start,
@@ -575,66 +625,3 @@ class DCLProject:
         plt.subplots_adjust(hspace=0.2)
 
         return axes
-
-
-def plot_segments_on_capture(
-    capture,
-    segments,
-    capture_name,
-    labels=None,
-    current_start=0,
-    ylim=None,
-    figsize: Tuple = (30, 8),
-    currentAxis=None,
-):
-
-    if currentAxis is None:
-        plt.figure(figsize=figsize)
-        currentAxis = plt.gca()
-
-    cmap = plt.cm.rainbow
-
-    if labels is None:
-        labels = segments.label_value.unique().tolist()
-
-    delta = 1 / len(labels)
-    label_float = np.arange(0, 1, delta)
-    label_float[-1] = 1.0
-
-    label_colors = {labels[index]: cmap(x) for index, x in enumerate(label_float)}
-    label_legend = [Line2D([0], [0], color=cmap(x), lw=4) for x in label_float] + [
-        Line2D([0], [0], color="white", lw=4)
-    ]
-
-    for _, seg in segments.iterrows():
-        y_origin = capture.describe().loc["min"].min() if ylim is None else ylim[0]
-        x_origin = seg["capture_sample_sequence_start"] + current_start
-        x_final = (
-            seg["capture_sample_sequence_end"] - seg["capture_sample_sequence_start"]
-        )
-        y_final = (
-            capture.describe().loc["max"].max() - y_origin
-            if ylim is None
-            else ylim[1] - ylim[0]
-        )
-
-        currentAxis.add_artist(
-            plt.Rectangle(
-                (x_origin, y_origin),
-                x_final,
-                y_final,
-                alpha=0.2,
-                color=label_colors[seg["label_value"]],
-            )
-        )
-
-    currentAxis.legend(label_legend, labels + [""])
-
-    currentAxis.text(
-        current_start,
-        0 if ylim is None else ylim[0],
-        capture_name,
-        style="italic",
-        rotation=90,
-        # bbox={"facecolor": "grey", "alpha": 0.5, "pad": 10},
-    )
