@@ -112,6 +112,14 @@ class Pipeline(object):
         else:
             print("Error: group_columns must be a list.")
 
+    def to_list(self):
+        """Converts the current pipeline into its List form
+
+        Returns:
+            List:
+        """
+        return self._sandbox._pipeline.to_list()
+
     def get_automl_iteration_metrics(self):
         """
         Results of automl stats for each iteration
@@ -552,7 +560,7 @@ class Pipeline(object):
         # check that the pipeline is correct for autosegmentation.
         for step_index, step in enumerate(self._sandbox.pipeline.to_list()):
             if step_index == 0:
-                if step["type"] != "featurefile":
+                if step["type"] not in ["featurefile", "datafile", "capturefile"]:
                     print("First step in pipeline must be a featurefile")
                     return None, None
             else:
@@ -785,8 +793,49 @@ class Pipeline(object):
 
         """
 
+        if data_columns is None:
+            raise Exception("data_columns can not be None")
+
+        if not isinstance(data_columns, list):
+            raise Exception("data_columns must be a list")
+
+        if label_column and label_column not in group_columns:
+            raise Exception("Label column must be a group column!")
+
         self.set_columns(data_columns, group_columns, label_column)
 
+        if isinstance(name, list):
+            for index, csv_name in enumerate(name):
+                if csv_name[-4:] != ".csv":
+                    name[index] = "{}.csv".format(csv_name)
+        else:
+            if name[-4:] != ".csv":
+                name = "{}.csv".format(name)
+
+        call = self._kb.functions.create_datafile_call(name)
+        self._dataset = call
+        self._dataset.data_columns = self.data_columns
+        self._dataset.group_columns = self.group_columns
+        self._dataset.label_column = self.label_column
+
+        self._add_initial_data()
+
+    def set_input_features(
+        self, name, feature_columns=None, group_columns=None, label_column=None
+    ):
+        """Use a feature file as input to the pipeline (features have already been generated in this case)
+
+        Args:
+            name (str, list): The name of the data file or list of feature files in SensiML cloud.
+            feature_columns (list, required): Array of data streams to use in model building.
+            group_columns (list, required): The List of columns to use when applying aggregate functions
+                and defining unique subsets on which to operate.
+            label_column (str, required): The column with the true classification.
+
+        """
+
+        self.set_columns(feature_columns, group_columns, label_column)
+
         if isinstance(name, list):
             for index, csv_name in enumerate(name):
                 if csv_name[-4:] != ".csv":
@@ -797,13 +846,13 @@ class Pipeline(object):
 
         call = self._kb.functions.create_featurefile_call(name)
         self._dataset = call
-        self._dataset.data_columns = self.data_columns
+        self._dataset.feature_columns = self.data_columns
         self._dataset.group_columns = self.group_columns
         self._dataset.label_column = self.label_column
 
         self._add_initial_data()
 
-    def set_input_capture(self, names):
+    def set_input_capture(self, names, group_columns=None):
         """Use a data file that has been uploaded as your data source.
 
         Args:
@@ -811,11 +860,15 @@ class Pipeline(object):
 
         """
 
-        self.set_columns(list(self._project.columns()), ["Subject"], None)
+        if group_columns is None:
+            group_columns = ["segment_uuid", "capture_uuid"]
+
+        self.set_columns(list(self._project.columns()), group_columns, None)
 
         call = self._kb.functions.create_capturefile_call(names)
         self._dataset = call
         self._dataset.data_columns = self.data_columns
+        self._dataset.group_columns = self.group_columns
 
         self._add_initial_data()
 
